package com.chinaitop.depot.archives.controller;

import java.io.IOException;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import com.chinaitop.depot.archives.model.StorageQualitycheckArchives;
import com.chinaitop.depot.archives.model.StorageQualitycheckArchivesExample;
import com.chinaitop.depot.archives.model.StorageQualitycheckArchivesSon;
import com.chinaitop.depot.archives.service.QualitycheckArchivesService;
import com.chinaitop.depot.storage.model.StorageQualitycheck;
import com.chinaitop.depot.storage.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(value="/QualitycheckArchivesController")
@Api(value= "QualitycheckArchivesController", description = "质量档案类")
public class QualitycheckArchivesController {

	@Resource
	private QualitycheckArchivesService qualitycheckArchivesService;
    
	@RequestMapping(value = "/getList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
	@ApiOperation(value="质量档案管理列表", notes = "质量档案管理信息列表，支持分页")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
			@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
			@ApiImplicitParam(name = "storehouseId", value = "仓房ID", paramType = "query"),
			@ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query")
	})
	public PageInfo<StorageQualitycheck> getList(Integer pageNum, Integer pageSize,String storehouseId, Integer orgId) {
		if (pageNum!=null && pageSize!=null) {
			PageHelper.startPage(pageNum, pageSize);
		}

		List<StorageQualitycheck> list = qualitycheckArchivesService.findCondition(storehouseId,orgId);

		PageInfo<StorageQualitycheck> pageInfo = new PageInfo<StorageQualitycheck>(list);
		return pageInfo;
	}

	/**
	 * 保存质量档案的初检信息
	 * @param qualityArchives
	 * @return
	 */
	@RequestMapping(value="/saveCJData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value="保存初检信息", notes = "保存质量档案的初检信息")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "qualityArchives", value = "质量档案信息", paramType = "form")
	})
	public Map<String, Object> saveCJData(String qualityArchives) throws Exception {
		Map<String, Object> modelMap = qualitycheckArchivesService.saveCJData(qualityArchives);
		return modelMap;
	}

	/**
	 * 保存质量档案的初检信息
	 * @param id
	 * @return
	 */
	@RequestMapping(value="/getQualityArchivesDeatil", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value="保存初检信息", notes = "保存质量档案的初检信息")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "id", value = "质量档案id", paramType = "form")
	})
	public StorageQualitycheckArchives getQualityArchivesDeatil(String id) throws Exception {
		StorageQualitycheckArchives modelMap = qualitycheckArchivesService.getQualityArchivesDeatil(id);
		return modelMap;
	}

	/**
	 * 删除质量档案的信息
	 * @param id
	 * @return
	 */
	@RequestMapping(value="/removeById", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value="删除质量档案", notes = "删除质量档案的信息")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "id", value = "质量档案id", paramType = "form")
	})
	public Map<String, Object> removeById(String id) throws Exception {
		Map<String, Object> modelMap = qualitycheckArchivesService.removeById(id);
		return modelMap;
	}

	/**
	 * 保存质量档案的出库信息
	 * @param qualityCK1
	 * @param qualityCK2
	 * @return
	 */
	@RequestMapping(value="/saveCKData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value="保存出库信息", notes = "保存质量档案的出库信息")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "qualityCK1", value = "第一批数据", paramType = "form"),
			@ApiImplicitParam(name = "qualityCK2", value = "第二批数据", paramType = "form")
	})
	public Map<String, Object> saveCKData(String qualityCK1,String qualityCK2) throws Exception {
		Map<String, Object> modelMap = qualitycheckArchivesService.saveCKData(qualityCK1,qualityCK2);
		return modelMap;
	}

	/**
	 * 保存质量档案的初检信息
	 * @param archivesId
	 * @param acceptanceId
	 * @return
	 */
	@RequestMapping(value="/saveYSData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value="保存初检信息", notes = "保存质量档案的初检信息")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "archivesId", value = "档案id", paramType = "form"),
			@ApiImplicitParam(name = "acceptanceId", value = "验收id", paramType = "form")
	})
	public Map<String, Object> saveYSData(String archivesId,String acceptanceId) throws Exception {
		Map<String, Object> modelMap = qualitycheckArchivesService.saveYSData(archivesId,acceptanceId);
		return modelMap;
	}

	/**
	 * 根据档案id查询子表数据
	 * @param id
	 * @return
	 */
	@RequestMapping(value="/getSonByArchivesId", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value="根据档案id查询子表数据", notes = "根据档案id查询子表数据")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "id", value = "档案id", paramType = "form")
	})
	public Map<String, Object> getSonByArchivesId(String id) throws Exception {
		Map<String, Object> modelMap = qualitycheckArchivesService.getSonByArchivesId(id);
		return modelMap;
	}

	@RequestMapping(value = "/getDQandRCPageInfo",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
	@ApiOperation(value="检测列表", notes = "检测列表，支持分页")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
			@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
			@ApiImplicitParam(name = "startDate", value = "开始检测", paramType = "query"),
			@ApiImplicitParam(name = "endDate", value = "结束检测", paramType = "query"),
			@ApiImplicitParam(name = "archivesId", value = "档案id", paramType = "query"),
			@ApiImplicitParam(name = "inspectionType", value = "检验类型", paramType = "query"),
			@ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query")
	})
	public PageInfo<StorageQualitycheckArchivesSon> getDQandRCPageInfo(Integer pageNum, Integer pageSize,String startDate, String endDate, String archivesId, String inspectionType, Integer orgId) {
		if (pageNum!=null && pageSize!=null) {
			PageHelper.startPage(pageNum, pageSize);
		}

		List<StorageQualitycheckArchivesSon> list = qualitycheckArchivesService.findRegular(startDate,endDate,archivesId,inspectionType,orgId);

		PageInfo<StorageQualitycheckArchivesSon> pageInfo = new PageInfo<StorageQualitycheckArchivesSon>(list);
		return pageInfo;
	}

	/**
	 * 保存质量档案的检验
	 * @param qualitySon
	 * @return
	 */
	@RequestMapping(value="/saveArchiveSonData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value="保存检验", notes = "保存质量档案的检验")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "qualitySon", value = "检验数据", paramType = "form")
	})
	public Map<String, Object> saveArchiveSonData(String qualitySon) throws Exception {
		Map<String, Object> modelMap = qualitycheckArchivesService.saveArchiveSonData(qualitySon);
		return modelMap;
	}

	/**
	 * 删除定期检测的信息
	 * @param id
	 * @return
	 */
	@RequestMapping(value="/removeRegularById", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value="删除定期检测", notes = "删除定期检测的信息")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "id", value = "质量档案id", paramType = "form")
	})
	public Map<String, Object> removeRegularById(String id) throws Exception {
		Map<String, Object> modelMap = qualitycheckArchivesService.removeRegularById(id);
		return modelMap;
	}

	/**
	 * 根据id查询检测
	 * @param id
	 * @return
	 */
	@RequestMapping(value="/getArchivesSonById", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value="根据id查询检测", notes = "根据id查询检测信息")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "id", value = "质量档案子表id", paramType = "form")
	})
	public StorageQualitycheckArchivesSon getArchivesSonById(String id) throws Exception {
		return qualitycheckArchivesService.getArchivesSonById(id);
	}

	/**
	 * 根据id查询检测
	 * @param archivesId
	 * @return
	 */
	@RequestMapping(value="/getPrintData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value="根据id查询检测", notes = "根据id查询检测信息")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "archivesId", value = "质量档案id", paramType = "form")
	})
	public Map<String, Object> getPrintData(String archivesId) throws Exception {
		return qualitycheckArchivesService.getPrintData(archivesId);
	}
}
