package com.chinaitop.depot.archives.service.impl;

import javax.annotation.Resource;

import com.chinaitop.depot.archives.mapper.StorageQualitycheckArchivesMapper;
import com.chinaitop.depot.archives.mapper.StorageQualitycheckArchivesSonMapper;
import com.chinaitop.depot.archives.model.StorageQualitycheckArchives;
import com.chinaitop.depot.archives.model.StorageQualitycheckArchivesSon;
import com.chinaitop.depot.archives.model.StorageQualitycheckArchivesSonExample;
import com.chinaitop.depot.storage.mapper.StorageQualitycheckMapper;
import com.chinaitop.depot.storage.model.StorageQualitycheck;
import com.chinaitop.depot.storage.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import com.chinaitop.depot.archives.service.QualitycheckArchivesService;

import java.io.IOException;
import java.util.*;

@Service
public class QualitycheckArchivesServiceImpl implements QualitycheckArchivesService {

	@Resource
	private StorageQualitycheckMapper storageQualitycheckMapper;

	@Resource
	private StorageQualitycheckArchivesMapper storageQualitycheckArchivesMapper;

	@Resource
	private StorageQualitycheckArchivesSonMapper storageQualitycheckArchivesSonMapper;

	@Override
	public List<StorageQualitycheck> findCondition(String storehouseId, Integer orgId) {
		Map<String,Object> qualityMap = new HashMap<>();
		if(StringUtils.isNotBlank(storehouseId)) {
			if(storehouseId.contains("YG")){
				qualityMap.put("tankId",storehouseId);
			}else{
				qualityMap.put("storehouseId",storehouseId);
			}
		}
		qualityMap.put("orgId",orgId);
		return storageQualitycheckMapper.selectByArchives(qualityMap);
	}

	@Override
	public Map<String, Object> saveCJData(String qualityArchives) {

		Map<String, Object> modelMap = new HashMap<String, Object>();
		// JSON字符串转对象
		ObjectMapper mapper = new ObjectMapper();
		StorageQualitycheckArchives qualitycheckArchives = null;
		try {
			qualitycheckArchives = (StorageQualitycheckArchives) mapper.readValue(qualityArchives, StorageQualitycheckArchives.class);

			if (qualitycheckArchives.getId() == null) {
				qualitycheckArchives.setId(ParameterUtil.getCode());
				qualitycheckArchives.setCreateTime(new Date());//创建时间
				storageQualitycheckArchivesMapper.insert(qualitycheckArchives);//熏蒸计划
			} else {
				storageQualitycheckArchivesMapper.updateByPrimaryKey(qualitycheckArchives);
			}
			modelMap.put("status", "success");
		} catch (IOException e) {
			modelMap.put("status", "error");
			e.printStackTrace();
		}
		return modelMap;
	}

	@Override
	public Map<String, Object> saveYSData(String archivesId,String acceptanceId) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		StorageQualitycheckArchives qualitycheckArchives = new StorageQualitycheckArchives();

		qualitycheckArchives.setId(archivesId);
		qualitycheckArchives.setAcceptanceId(Integer.valueOf(acceptanceId));

		storageQualitycheckArchivesMapper.updateByPrimaryKeySelective(qualitycheckArchives);
		modelMap.put("status", "success");
		return modelMap;
	}

	@Override
	public Map<String, Object> saveCKData(String qualityCK1,String qualityCK2) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		// JSON字符串转对象
		ObjectMapper mapper = new ObjectMapper();
		StorageQualitycheckArchivesSon qualitycheckArchives = null;
		try {
			qualitycheckArchives = (StorageQualitycheckArchivesSon) mapper.readValue(qualityCK1, StorageQualitycheckArchivesSon.class);

			if(ParameterUtil.isnotnull(qualitycheckArchives.getArchivesId())){
				qualitycheckArchives.setId(ParameterUtil.getCode());
				qualitycheckArchives.setCreateTime(new Date());//创建时间
				storageQualitycheckArchivesSonMapper.insert(qualitycheckArchives);
			}

			qualitycheckArchives = (StorageQualitycheckArchivesSon) mapper.readValue(qualityCK2, StorageQualitycheckArchivesSon.class);

			if(ParameterUtil.isnotnull(qualitycheckArchives.getArchivesId())){
				qualitycheckArchives.setId(ParameterUtil.getCode());
				qualitycheckArchives.setCreateTime(new Date());//创建时间
				storageQualitycheckArchivesSonMapper.insert(qualitycheckArchives);
			}

			modelMap.put("status", "success");
		} catch (IOException e) {
			modelMap.put("status", "error");
			e.printStackTrace();
		}
		return modelMap;
	}

	@Override
	public StorageQualitycheckArchives getQualityArchivesDeatil(String id) {
		return storageQualitycheckArchivesMapper.selectByPrimaryKey(id);
	}

	@Override
	public Map<String, Object> removeById(String id) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		storageQualitycheckArchivesMapper.deleteByPrimaryKey(id);

		StorageQualitycheckArchivesSonExample example = new StorageQualitycheckArchivesSonExample();
		StorageQualitycheckArchivesSonExample.Criteria criteria = example.createCriteria();
		criteria.andArchivesIdEqualTo(id);
		storageQualitycheckArchivesSonMapper.deleteByExample(example);

		modelMap.put("status", "success");
		return modelMap;
	}

	@Override
	public Map<String, Object> getSonByArchivesId(String id) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		StorageQualitycheckArchivesSonExample example = new StorageQualitycheckArchivesSonExample();
		StorageQualitycheckArchivesSonExample.Criteria criteria = example.createCriteria();
		criteria.andArchivesIdEqualTo(id);
		List<StorageQualitycheckArchivesSon> sonList = storageQualitycheckArchivesSonMapper.selectByExample(example);
		modelMap.put("archivesSon", sonList);
		return modelMap;
	}

	@Override
	public List<StorageQualitycheckArchivesSon> findRegular(String startDate, String endDate, String archivesId, String inspectionType, Integer orgId) {
		Map<String,Object> qualityMap = new HashMap<>();
		if(ParameterUtil.isnotnull(startDate) && ParameterUtil.isnotnull(endDate)){
			qualityMap.put("startDate",startDate);
			qualityMap.put("endDate",endDate);
		}
		qualityMap.put("archivesId",archivesId);
		qualityMap.put("orgId",orgId);
		qualityMap.put("inspectionType",inspectionType);
		return storageQualitycheckArchivesSonMapper.selectByExamples(qualityMap);
	}

	@Override
	public Map<String, Object> saveArchiveSonData(String qualitySon) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		// JSON字符串转对象
		ObjectMapper mapper = new ObjectMapper();
		StorageQualitycheckArchivesSon qualitycheckArchives = null;
		try {
			qualitycheckArchives = (StorageQualitycheckArchivesSon) mapper.readValue(qualitySon, StorageQualitycheckArchivesSon.class);

			if(ParameterUtil.isnotnull(qualitycheckArchives.getArchivesId())){
				qualitycheckArchives.setId(ParameterUtil.getCode());
				qualitycheckArchives.setCreateTime(new Date());//创建时间
				storageQualitycheckArchivesSonMapper.insert(qualitycheckArchives);
			}
			modelMap.put("status", "success");
		} catch (IOException e) {
			modelMap.put("status", "error");
			e.printStackTrace();
		}
		return modelMap;
	}

	@Override
	public Map<String, Object> removeRegularById(String id) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		storageQualitycheckArchivesSonMapper.deleteByPrimaryKey(id);
		modelMap.put("status", "success");
		return modelMap;
	}

	@Override
	public StorageQualitycheckArchivesSon getArchivesSonById(String id) {
		return storageQualitycheckArchivesSonMapper.selectByPrimaryKey(id);
	}

	@Override
	public Map<String, Object> getPrintData(String archivesId) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		List<Map<String, Object>> storageQualitycheckArchives = ParameterUtil.slashCapitals(storageQualitycheckArchivesMapper.selectById(archivesId));
		modelMap.put("qualityArchives", storageQualitycheckArchives.get(0));
		List<Map<String, Object>> archivesSon = ParameterUtil.slashCapitals(storageQualitycheckArchivesSonMapper.selectByArchivesId(archivesId));
		List<Map<String, Object>> DQList = new ArrayList<Map<String,Object>>();
		List<Map<String, Object>> RCList = new ArrayList<Map<String,Object>>();
		for (Map<String, Object> arSon:archivesSon) {
			modelMap.put(arSon.get("inspectionType").toString(), arSon);

			if (ParameterUtil.isequal(arSon.get("inspectionType").toString(),"DQ")){
				DQList.add(arSon);
			}else if (ParameterUtil.isequal(arSon.get("inspectionType").toString(),"RC")){
				RCList.add(arSon);
			}
		}

		List<Map<String, Object>> RCLists = new ArrayList<Map<String,Object>>(21);
		Integer j = 0;
		for (int i = 0; i < 21; i++) {
			if(j<RCList.size()){
				RCLists.add(RCList.get(j));
				j++;
				if(j<RCList.size()){
					RCLists.get(i).put("checkTimes",RCList.get(j).get("checkTime"));
					RCLists.get(i).put("dailyCws",RCList.get(j).get("dailyCw"));
					RCLists.get(i).put("dailyLws",RCList.get(j).get("dailyLw"));
					RCLists.get(i).put("waters",RCList.get(j).get("water"));
				}
				j++;
			}else{
				RCLists.add(i,new HashMap<String, Object>());
			}
			RCLists.get(i).put("empty","&emsp;");
		}
		modelMap.put("DQList", DQList);
		modelMap.put("RCList", RCLists);
		return modelMap;
	}
}