package com.chinaitop.depot.storage.controller;


import com.chinaitop.depot.storage.model.*;
import com.chinaitop.depot.storage.model.StorageQualitycheckExample.Criteria;
import com.chinaitop.depot.storage.service.StorageFoodbasicInfoService;
import com.chinaitop.depot.storage.service.StorageQualitycheckInspectionService;
import com.chinaitop.depot.storage.service.StorageQualitycheckService;
import com.chinaitop.depot.storage.service.StorageQualitycheckSonService;
import com.chinaitop.depot.storage.utils.DataSynchronization;
import com.chinaitop.depot.storage.utils.ParameterUtil;
import com.chinaitop.depot.storage.utils.createKC;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.IOException;
import java.sql.Timestamp;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * Created by product on 2017/10/11.
 */
@RestController
@RequestMapping(value = {"/qualitycheck"})
@Api(value= "StorageQualitycheckController", description = "质量管理控制类")
public class StorageQualitycheckController {
    @Resource
    private StorageQualitycheckService storageQualitycheckService;

    @Resource
    private StorageQualitycheckSonService qualitycheckSonService;

    @Resource
    private StorageQualitycheckInspectionService qualitycheckInspectionService;

    @Resource
    private StorageFoodbasicInfoService foodbasicInfoService;

    // 获取ip地址
    @Value("${crk-webservice}")
    private String url;

    /**
     * 封仓管理中查询出未封仓的质量管理信息，已经封仓的不要展示
     * 分页获取
     */
    @RequestMapping(value = "/getList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="查询质量管理列表", notes = "查询质量管理信息列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "qualitycheck", value = "实体类", paramType = "query"),
            @ApiImplicitParam(name = "storehouseId", value = "仓房", paramType = "query"),
            @ApiImplicitParam(name = "checktype", value = "检查的类型", paramType = "query"),
            @ApiImplicitParam(name = "checkResult", value = "检查结果", paramType = "query")
    })
    public PageInfo<StorageQualitycheck> listPage(Integer pageNum, Integer pageSize,
                                                  StorageQualitycheck qualitycheck, String storehouseId,String checktype,String checkResult) {
    	StorageQualitycheck qualityCheck = new StorageQualitycheck();
        //根据后台传来的参数进行查找相应类型的类别0:初检 1：验收 2：质量普查 3：出库
        if (StringUtils.isNotBlank(checktype)){
            qualityCheck.setType(checktype);
        }

        // 仓房id.
        if(StringUtils.isNotBlank(storehouseId)) {
            if(storehouseId.contains("YG")){
                qualityCheck.setTankId(storehouseId);
            }else{
                qualityCheck.setHouseId(Integer.valueOf(storehouseId));
            }
        }

        // 货位id.
        if (qualitycheck.getWarehouseId() != null) {
            qualityCheck.setWarehouseId(qualitycheck.getWarehouseId());
        }

        // 粮库id.
        if (qualitycheck.getOrgId() != null) {
            qualityCheck.setOrgId(qualitycheck.getOrgId());
        }
        
        // 明细品种.
        if (qualitycheck.getSubTypeDetailed() != null) {
            qualityCheck.setSubTypeDetailed(qualitycheck.getSubTypeDetailed());
        }
        
        // 等级.
        if (qualitycheck.getLevel() != null) {
            qualityCheck.setLevel(qualitycheck.getLevel());
        }

        //检验结果（0：合格 , 1 :不合格）

        if (StringUtils.isNotBlank(checkResult)) {
            qualityCheck.setCheckResult(checkResult);
        }
        qualityCheck.setHistoryStatus(0);//0:最新数据  1:历史数据
        //查询出未封仓的质量管理信息 封仓状态：0:未封仓,1:已封仓
        //qualityCheck.setSealStatus("0");
        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<StorageQualitycheck> list = storageQualitycheckService.queryByQualitycheck(qualityCheck);

        PageInfo<StorageQualitycheck> pageInfo = new PageInfo<StorageQualitycheck>(list);
        if(pageInfo.getList()!=null && pageInfo.getTotal() >0){
            pageInfo.setStartRow(pageInfo.getStartRow());
            pageInfo.setEndRow(pageInfo.getEndRow());
        }
        return pageInfo;
    }
    
    /**
     * 获取仓房或者货位(通过分组查询最新的满足条件的仓房或者货位).
     * @param qualitycheck
     * @return
     */
    @RequestMapping(value = "/getHouseOrWareList",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="获取仓房或者货位(通过分组查询最新的满足条件的仓房或者货位)", notes = "获取仓房或者货位(通过分组查询最新的满足条件的仓房或者货位)")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "qualitycheck", value = "质量管理对象", paramType = "query")
    })
    public List<StorageQualitycheck> getHouseIdList(StorageQualitycheck qualitycheck) {
        List<StorageQualitycheck> list = storageQualitycheckService.getHouseOrWareList(qualitycheck);
        return list;
    }
    
    /**
     * 获取第三方检验的质量标准字符串(手动拼写)
     * @param id
     * @return
     */
    @RequestMapping(value = "/getQualityStandardStr",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="获取第三方检验的质量标准字符串(手动拼写)", notes = "获取第三方检验的质量标准字符串(手动拼写)")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "form"),
    })
    public Map<String, Object> getQualityStandardStr(Integer id) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        if (id == null) {
            modelMap.put("status", "error");
            modelMap.put("msg", "id为空，查询质量标准失败！");
        } else {
            String qualityStandardStr = storageQualitycheckService.getQualityStandardStr(id);
            modelMap.put("status", "success");
            modelMap.put("qualityStandard", qualityStandardStr);
        }

        return modelMap;
    }
    
    

    /**
     * 新增和修改的数据进行保存
     * @param qualitycheckJson
     * @return
     */
    @RequestMapping(value="/save", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="新增/修改数据", notes = "新增/修改数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "storehouseId", value = "仓房油罐id", paramType = "query"),
            @ApiImplicitParam(name = "qualitycheckInspection", value = "质量基础信息JSON数据对象", paramType = "form"),
            @ApiImplicitParam(name = "qualitycheckJson", value = "质量基础信息JSON数据对象", paramType = "form"),
            @ApiImplicitParam(name = "qualityOneJson", value = "质量检测信息JSON数据对象", paramType = "form")
    })
    public Map<String, Object> save(String storehouseId,String qualitycheckInspection,String qualitycheckJson,String qualityOneJson) {
        Map<String, Object> modelMap = new HashMap<>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        StorageQualitycheck qualitycheck = null;
        List<StorageQualitycheckSon> qualitycheckone = null;
        try {
            qualitycheck = (StorageQualitycheck)mapper.readValue(qualitycheckJson, StorageQualitycheck.class);
            //默认0:未封仓   1:已封仓
            qualitycheck.setSealStatus("0");
            qualitycheck.setHistoryStatus(0);//0:最新数据   1:历史数据
            if (null!=qualitycheck.getQfrq()){

            }else {
                qualitycheck.setQfrq(null);
            }
            Integer qualityCheckId = storageQualitycheckService.save(qualitycheck,storehouseId);
            //油罐检测信息
            if(StringUtils.isNoneBlank(qualitycheckInspection)){
                StorageQualitycheckInspection qualityInspection = (StorageQualitycheckInspection)mapper.readValue(qualitycheckInspection, StorageQualitycheckInspection.class);
                qualityInspection.setQualitycheckId(qualityCheckId);
                qualitycheckInspectionService.save(qualityInspection);

            }
            //关联保存日常检查和第三方检测的检测信息 如果为空则是对初检 验收等操作
            if(StringUtils.isNoneBlank(qualityOneJson)){
                qualitycheckone = mapper.readValue(qualityOneJson,  new TypeReference<List<StorageQualitycheckSon>>(){});
                for (int i = 0; i < qualitycheckone.size(); i++) {
                    qualitycheckone.get(i).setQualitycheckId(qualityCheckId);
                    storageQualitycheckService.saveOne(qualitycheckone.get(i));
                }
            }
            modelMap.put("status", "success");
        } catch (IOException e) {
            modelMap.put("status", "error");
            e.printStackTrace();
        }
        return modelMap;
    }

    /**
     * 根据id加载对应数据
     * @param id
     * @return
     */
    @RequestMapping(value = "/loadDataById" ,produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据id加载质量检查数据", notes = "根据id加载质量检查数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "query"),
    })
    public Map<String, Object>  loadDataById(Integer id){
        Map<String,Object> retMap = new HashMap<String,Object>();
        //获取主表数据
        StorageQualitycheck qualitycheck=storageQualitycheckService.loadDataById(id);
        retMap.put("qualitycheck",qualitycheck);

        if(qualitycheck!=null){
            StorageQualitycheckInspection qualitycheckInspection = qualitycheckInspectionService.loadDataById(id);
            retMap.put("qualitycheckInspection",qualitycheckInspection);
        }

        return retMap;
    }

    /**
     * 根据主键id移除数据
     * @param id
     * @return
     */
    @RequestMapping(value="/remove", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="按ID删除质量检查信息", notes = "按ID删除质量检查信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "数据ID", paramType = "form")
    })
    public Map<String, Object> remove(Integer id){
        Map<String,Object> retMap = new HashMap<String,Object>();
        storageQualitycheckService.remove(id);

        //删除管理的数据
        StorageQualitycheckSonExample qualitycheckSonExample = new StorageQualitycheckSonExample();
        StorageQualitycheckSonExample.Criteria criteria = qualitycheckSonExample.createCriteria();
        if(id != null){
            criteria.andQualitycheckIdEqualTo(id);
        }
        qualitycheckSonService.removeSon(qualitycheckSonExample);
        retMap.put("msg","success");
        return retMap;
    }

    /**
     * 封仓管理中查询出所有仓已经封仓或者未封仓的质量管理信息
     * @param
     * @param warehouseId
     * @return
     */
    @RequestMapping(value="/getFoodsealList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="封仓管理列表中查询出封仓或未封仓的质量管理信息", notes = "封仓管理列表中查询出封仓或未封仓的质量管理信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位ID", paramType = "query")
    })
    public PageInfo<StorageQualitycheck> listPage(Integer pageNum, Integer pageSize ,
                                                  String storehouseId, String warehouseId) {
    	StorageQualitycheck qualityCheck = new StorageQualitycheck();

        // 仓房id.
        if(StringUtils.isNotBlank(storehouseId)) {
            if(storehouseId.contains("YG")){
                qualityCheck.setTankId(storehouseId);
            }else{
                qualityCheck.setHouseId(Integer.valueOf(storehouseId));
            }
        }

        if(StringUtils.isNoneBlank(warehouseId)){
            qualityCheck.setWarehouseId(Integer.valueOf(warehouseId));
        }
//        qualityCheck.setType("1");///查找验收质量管理的信息
        qualityCheck.setType("0");///查找初检质量管理的信息

        qualityCheck.setHistoryStatus(0);//0:最新数据  1:历史数据

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }

        List<StorageQualitycheck> list = storageQualitycheckService.queryByQualitycheck(qualityCheck);

        PageInfo<StorageQualitycheck> pageInfo = new PageInfo<StorageQualitycheck>(list);
        return pageInfo;
    }

    /**
     * 根据仓号,货位号以及类型查找对应质量检查信息
     * @param storehouseId
     * @param warehouseId
     * @param type
     * @param sealStatus
     * @return
     */
    @RequestMapping(value = "/findByStoreWarehouse", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据仓号,货位号以及类型查找对应质量检查信息", notes = "根据仓号,货位号以及类型查找对应质量检查信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "storehouseId", value = "仓房ID", paramType = "query"),
            @ApiImplicitParam(name = "tankId", value = "油罐仓房ID", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位ID", paramType = "query"),
            @ApiImplicitParam(name = "id", value = "货位ID", paramType = "query"),
            @ApiImplicitParam(name = "type", value = "检查类型", paramType = "query"),
            @ApiImplicitParam(name = "sealStatus", value = "封仓类型", paramType = "query")
    })
    public StorageQualitycheck findByStoreWarehouse(Integer id,String storehouseId,String tankId, Integer warehouseId, String type,String sealStatus) {
    	StorageQualitycheck qualityCheckExample = new StorageQualitycheck();
        StorageQualitycheck qualitycheck = null;
        try {
            if(StringUtils.isNotBlank(storehouseId)) {
                if(storehouseId.contains("YG")){
                    qualityCheckExample.setTankId(storehouseId);
                }else{
                    qualityCheckExample.setHouseId(Integer.valueOf(storehouseId));
                }
            }
            if(tankId != null && !"".equals(tankId)) {
                if(tankId.contains("YG")){
                    qualityCheckExample.setTankId(tankId);
                }
            }
            if(warehouseId != null && !"".equals(warehouseId)){
                qualityCheckExample.setWarehouseId(warehouseId);
            }

            if(id != null && !"".equals(id)){
                qualityCheckExample.setId(id);
            }

            if(StringUtils.isNotBlank(type)){
                qualityCheckExample.setType(type);//传入查找的质量类型
            }

            if(StringUtils.isNotBlank(sealStatus)){
                qualityCheckExample.setSealStatus(sealStatus);//传入查找的质量类型
            }
            //0:最新数据  1:历史数据
            qualityCheckExample.setHistoryStatus(0);
            List<StorageQualitycheck> list = storageQualitycheckService.queryByQualitycheck(qualityCheckExample);
            if (null != list && list.size() > 0) {
            	qualitycheck = list.get(0);
            }

        } catch (Exception e) {
            e.printStackTrace();
        }
        return qualitycheck;
    }

    /**
     *
     * @param storehouseId
     * @param warehouseId
     * @param type
     * @param id
     * @return
     */
    @RequestMapping(value = "/findByStoreWarehouseData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据仓号,货位号以及类型查找对应信息", notes = "根据仓号,货位号以及类型查找对应信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位ID", paramType = "query"),
            @ApiImplicitParam(name = "type", value = "检查类型", paramType = "query"),
            @ApiImplicitParam(name = "id", value = "检查id", paramType = "query")
    })
    public StorageFoodbasicinfo findByStoreWarehouseData(String storehouseId, Integer warehouseId, String type , Integer id) {
        StorageQualitycheck qualityCheckExample = new StorageQualitycheck();
        StorageFoodbasicinfo foodbasicinfo = new StorageFoodbasicinfo();
        try {

            if(StringUtils.isNotBlank(type)){
                qualityCheckExample.setType(type);//传入查找的质量类型
            }

            if (id != null && !"".equals(id)) {
                qualityCheckExample.setId(id);
            }

            //0:最新数据  1:历史数据
            qualityCheckExample.setHistoryStatus(0);
            //查询出未封仓的质量管理信息 封仓状态：0:未封仓,1:已封仓
            qualityCheckExample.setSealStatus("0");

            //查看business_store_ware_detail中价格是否有
            List<StorageQualitycheck> businessList = storageQualitycheckService.queryByQualitycheckusiness(qualityCheckExample);
            if(null != businessList && businessList.size() > 0){
                qualityCheckExample.setNotice(1);
            }

            List<StorageQualitycheck> list = storageQualitycheckService.queryByQualitycheckData(qualityCheckExample);
            if (null != list && list.size() > 0) {
                foodbasicinfo.setHeight(list.get(0).getHeight());
                foodbasicinfo.setDisperseCapacity(list.get(0).getDisperseCapacity());
                foodbasicinfo.setKeepMethod(list.get(0).getKeepMethod());
                foodbasicinfo.setPrice(list.get(0).getPrice());
                foodbasicinfo.setStorageLocation(list.get(0).getDepotName());
                foodbasicinfo.setPlaceOfOrigin(String.valueOf(list.get(0).getLocation()));
                foodbasicinfo.setSubType(list.get(0).getSubType());//粮食品种
                foodbasicinfo.setNumber(Double.valueOf(list.get(0).getNumber()));//数量
                foodbasicinfo.setQuality(list.get(0).getQuality());//数量
                foodbasicinfo.setGrowYear(list.get(0).getHarvestTime());//收货年度
                foodbasicinfo.setLevel(String.valueOf(list.get(0).getLevel()));//d等级
                foodbasicinfo.setInputYear(list.get(0).getInputTime());//ruca入仓时间
                foodbasicinfo.setKeeperNames(list.get(0).getKeeper());//b保管员
            }

        } catch (Exception e) {
            e.printStackTrace();
        }
        return foodbasicinfo;
    }

    /**
     * 查询第三方检查
     * @param  foodbasicinfoId
     * @return getThirdCheckList
     */
    @RequestMapping(value="/getThirdCheckList",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="查询获得第三方检查列表", notes = "查询获得第三方检查列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位Id", paramType = "query"),
            @ApiImplicitParam(name = "foodbasicinfoId", value = "对应粮情专卡Id", paramType = "query"),

    })
    public PageInfo<StorageQualitycheck> getThirdCheckList(Integer pageNum, Integer pageSize , String houseId, Integer warehouseId,
                                                           Integer foodbasicinfoId) {
        StorageQualitycheck qualityCheck = new StorageQualitycheck();

        if(foodbasicinfoId != null){
            qualityCheck.setId(foodbasicinfoId);
        }
        if(StringUtils.isNotBlank(houseId)) {
            if(houseId.contains("YG")){
                qualityCheck.setTankId(houseId);
            }else{
                qualityCheck.setHouseId(Integer.valueOf(houseId));
            }
        }

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }

        List<StorageQualitycheck> list = storageQualitycheckService.getThirdCheckList(qualityCheck);

        PageInfo<StorageQualitycheck> pageInfo = new PageInfo<StorageQualitycheck>(list);
        return pageInfo;
    }

    /**
     * 和foodbasicinfoCheck关联得到粮情专卡中粮食质量检测记录(该记录包含当前仓房的验收信息和选择的第三方检验信息)
     * @param houseId
     * @param warehouseId
     * @param foodbasicinfoId
     * @return
     */
    @RequestMapping(value = "/getQualitycheckListByFoodbasicinfoCheck",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="和foodbasicinfoCheck关联得到粮情专卡中粮食质量检测记录", notes = "该记录包含当前仓房的验收信息和选择的第三方检验信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位Id", paramType = "query"),
            @ApiImplicitParam(name = "foodbasicinfoId", value = "对应粮情专卡Id", paramType = "query"),

    })
    public List<StorageQualitycheck> getQualitycheckListByFoodbasicinfoCheck(String houseId, Integer warehouseId, Integer foodbasicinfoId){
        StorageQualitycheck qualityCheck = new StorageQualitycheck();
        if(foodbasicinfoId != null){
            qualityCheck.setId(foodbasicinfoId);
        }

        // 仓房id.
        if(StringUtils.isNotBlank(houseId)) {
            if(houseId.contains("YG")){
                qualityCheck.setTankId(houseId);
            }else{
                qualityCheck.setHouseId(Integer.valueOf(houseId));
            }
        }

        if(warehouseId != null){
            qualityCheck.setWarehouseId(warehouseId);
        }
        List<StorageQualitycheck> list = storageQualitycheckService.getQualitycheckListByFoodbasicinfoCheck(qualityCheck,foodbasicinfoId);

        return list;
    }

    /**
     * 获取第三方检查的不宜存的可用数据
     * @return
     */
    
    @RequestMapping(value = "/getStoreQualityList",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET )
    @ApiOperation(value="获取第三方检查的不宜存的可用数据", notes = "获取第三方检查的不宜存的可用数据")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "orgId", value = "粮库id", paramType = "query")

    })
    public List<Map<String,Object>> getStoreQualityList(Integer orgId){
        List<Map<String,Object>> listQuality=storageQualitycheckService.getStoreQualityList(orgId);
        return listQuality;
    }

    /**
     * 获取第三方检查的不宜存的可用数据
     * @return
     */
    @RequestMapping(value = "/getTrdStoreQualityList",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET )
    @ApiOperation(value="获取第三方检查的不宜存的可用数据(集合格式)", notes = "获取第三方检查的不宜存的可用数据(集合格式)")
    public List<Map<String,Object>> getTrdStoreQualityList(){
    	List<Map<String,Object>> listQuality=storageQualitycheckService.getTrdStoreQualityList();    
        return listQuality;
    }
    
    
    @RequestMapping(value = "/setQualityCheckByHistoryStatus", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "根据仓房和货位名称更新当前质量管理为历史记录", notes = "根据仓房和货位名称更新当前质量管理为历史记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位Id", paramType = "query"),
    })
    public Map<String, Object> setQualityCheckByHistoryStatus(Integer houseId, Integer warehouseId) {
        Map<String, Object> modelMap = new HashMap<>();
        if (ParameterUtil.isnotnull(houseId) &&ParameterUtil.isnotnull(warehouseId) ) {
            storageQualitycheckService.setQualityCheckByHistoryStatus(houseId,warehouseId);
        }
        modelMap.put("status", "success");
        return modelMap;
    }

    /**
     * 根据id查询质检信息
     * @param ZZid
     * @return
     */
    @RequestMapping(value="/getDataByZJId", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
    @ApiOperation(value = "根据id查询质检信息", notes = "根据id查询质检信息,计划验收模块用到。")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "ZZid", value = "质检id", paramType = "query")
    })
    public Map<String,Object> getDataByZJId(Integer id ,Integer ZZid,Integer planType) {
        Map<String,Object> map = new HashMap<String, Object>();
        Map<String,Object> paramMap = new HashMap<String, Object>();
        paramMap.put("ZZid", ZZid);
        paramMap.put("id", id);
        paramMap.put("planType", planType+"");
        List<StorageQualitycheck> list = storageQualitycheckService.getDataByZJId(paramMap);
        map.put("qualitycheck", list);
        return map;
    }
    
    
    
    /**
     * 根据仓房和货位获取第三方检查的数据
     * 分页获取
     */
    @RequestMapping(value = "/getListByhouseId",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="根据仓房和货位获取第三方检查的数据", notes = "支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseIds", value = "仓房id(数组)", paramType = "query"),
            @ApiImplicitParam(name = "warehouseIds", value = "货位id(数组)", paramType = "query")
    })
    public PageInfo<StorageQualitycheck> getListByhouseId(Integer pageNum, Integer pageSize,
            Integer[] houseIds, Integer[] warehouseIds , String checktype) {
    	StorageQualitycheck qualityCheck = new StorageQualitycheck();
    	List<List<StorageQualitycheck>> list = new ArrayList<List<StorageQualitycheck>>();
        //根据后台传来的参数进行查找相应类型的类别0:初检 1：验收 2：质量普查 3：出库
        if (StringUtils.isNotBlank(checktype)){
            qualityCheck.setType(checktype);
        }
        
        qualityCheck.setHistoryStatus(0);//0:最新数据  1:历史数据
        //查询出未封仓的质量管理信息 封仓状态：0:未封仓,1:已封仓
        qualityCheck.setSealStatus("0");
        
        List<StorageQualitycheck> qualityCheckList =null;
        for (int i = 0; i < houseIds.length; i++) {
        	for (int j = 0; j < warehouseIds.length; j++) {
            	if(i==j){
            		Integer houseId = houseIds[i];
            		Integer warehouseId = warehouseIds[j];
            		 	//仓房id.
            	        if (qualityCheck.getHouseId() == null) {
            	            qualityCheck.setHouseId(houseId);

            	        }
            	        // 货位id.
            	        if (qualityCheck.getWarehouseId() == null) {
            	            qualityCheck.setWarehouseId(warehouseId);
            	        }
            	        if (pageNum!=null && pageSize!=null) {
            	            PageHelper.startPage(pageNum, pageSize);
            	        }
            	        
            	        qualityCheckList = storageQualitycheckService.queryByQualitycheck(qualityCheck);
            	}
    		}
		}
        
       
       
        PageInfo<StorageQualitycheck> pageInfo = new PageInfo<StorageQualitycheck>(qualityCheckList);
        return pageInfo;
    }

    @RequestMapping(value = "/getNewList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="查询质量管理列表", notes = "查询质量管理信息列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房ID", paramType = "query"),
            @ApiImplicitParam(name = "wareId", value = "货位ID", paramType = "query"),
            @ApiImplicitParam(name = "checktype", value = "检查的类型", paramType = "query"),
            @ApiImplicitParam(name = "checkResult", value = "检查结果", paramType = "query"),
            @ApiImplicitParam(name = "historyStatus", value = "数据状态", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query")
    })
    public PageInfo<StorageQualitycheck> newListPage(Integer pageNum, Integer pageSize, Integer houseId, Integer wareId,
                                                  String checkType, String checkResult, Integer historyStatus, Integer orgId) {
    	StorageQualitycheckExample example = new StorageQualitycheckExample();
    	Criteria criteria = example.createCriteria();

        //根据后台传来的参数进行查找相应类型的类别0:初检 1：验收 2：质量普查 3：出库
        if (StringUtils.isNotBlank(checkType)){
        	criteria.andTypeEqualTo(checkType);
        }
        // 仓房id.
        if (houseId != null) {
        	criteria.andHouseIdEqualTo(houseId);
        }
        // 货位id.
        if (wareId != null) {
        	criteria.andWarehouseIdEqualTo(wareId);
        }
        // 粮库id.
        if (orgId != null) {
        	criteria.andOrgIdEqualTo(orgId);
        }

        //检验结果（0：合格 , 1 :不合格）
        if (StringUtils.isNotBlank(checkResult)) {
        	criteria.andCheckResultEqualTo(checkResult);
        }
        //数据状态
        if (null != historyStatus) {
        	//0:最新数据  1:历史数据
        	criteria.andHistoryStatusEqualTo(historyStatus);
        }

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<StorageQualitycheck> list = storageQualitycheckService.findByCondition(example);

        PageInfo<StorageQualitycheck> pageInfo = new PageInfo<StorageQualitycheck>(list);
        return pageInfo;
    }

    /**
     *
     * @param houseId
     * @param warehouseId
     * @param orgId
     * @param level
     * @param crk_ip
     * @return
     */
    @RequestMapping(value="/updateLevel", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="修改数据", notes = "修改数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "houseId", value = "仓房油罐id", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "单位id", paramType = "query"),
            @ApiImplicitParam(name = "level", value = "等级", paramType = "query"),
            @ApiImplicitParam(name = "crk_ip", value = "出入库连接IP", paramType = "query")
    })
    public Map<String, Object>  updateLevel(String houseId, String warehouseId, String orgId, String level, String crk_ip) {

        Map<String, Object> modelMap = new HashMap<String, Object>();
        String crk_adr = "";
        try {
            Object[] parameters = new Object[5];
            parameters[0] = orgId + "";
            parameters[1] = houseId + "";
            parameters[2] = warehouseId + "";
            parameters[3] = level + "";
            parameters[4] = 2 + ""; //1:新增；2：修改；3：删除
            crk_adr = crk_ip+url;

            String str = createKC.createKC("ChangeGrainGrade", crk_adr, parameters);

            /* *****end******/
            if ("true".equals(str)) {
                modelMap.put("status", "success");
            } else {
                modelMap.put("status", "error");
                modelMap.put("msg", "等级修改失败");
                return modelMap;
            }

        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "等级修改失败");
        }
        return modelMap;
    }

    /**
     * 根据仓房和货位获取验收的数据
     * 分页获取
     */
    @RequestMapping(value = "/getPageInfoByChAndHw",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="根据仓房和货位获取验收的数据", notes = "支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseIds", value = "仓房id(数组)", paramType = "query"),
            @ApiImplicitParam(name = "warehouseIds", value = "货位id(数组)", paramType = "query")
    })
    public PageInfo<StorageQualitycheck> getPageInfoByChAndHw(Integer pageNum, Integer pageSize,
            Integer[] houseIds, Integer[] warehouseIds , String[] tankIds ,String checktype) {
    	
    	
    	StorageQualitycheck qualityCheck = new StorageQualitycheck();
        //根据后台传来的参数进行查找相应类型的类别0:初检 1：验收 2：质量普查 3：出库
        if (StringUtils.isNotBlank(checktype)){
            qualityCheck.setType(checktype);
        }
        
        qualityCheck.setHistoryStatus(0);//0:最新数据  1:历史数据
        
        List<StorageQualitycheck> qualityCheckList = null;
        List<StorageQualitycheck> qualityCheckListNew = new ArrayList<StorageQualitycheck>();
        
        //粮食
        if(houseIds!=null && warehouseIds!=null ){
        	if(houseIds.length>0 && warehouseIds.length>0){
            	for (int i = 0; i < houseIds.length; i++) {
                	for (int j = 0; j < warehouseIds.length; j++) {
                    	if(i==j){
                    		Integer houseId = houseIds[i];
                    		Integer warehouseId = warehouseIds[j];
                    		 	//仓房id.
                    	            qualityCheck.setHouseId(houseId);

                    	        // 货位id.
                    	            qualityCheck.setWarehouseId(warehouseId);
                    	        if (pageNum!=null && pageSize!=null) {
                    	            PageHelper.startPage(pageNum, pageSize);
                    	        }
                    	        
                    	        qualityCheckList = storageQualitycheckService.queryByQualitycheck(qualityCheck);
                    	        if(qualityCheckList!=null && qualityCheckList.size()>0){
                        	        qualityCheckListNew.add(qualityCheckList.get(0));
                    	        }
                    	}
            		}
        		}
            }
        }
        
        
        //油类
        if(tankIds!=null){
        	 if(tankIds.length>0){
             	for (int j = 0; j < tankIds.length; j++) {
                 		String tankId = tankIds[j];
                 	     // 油罐id.
                 	     qualityCheck.setTankId(tankId);
                 	    if (pageNum!=null && pageSize!=null) {
                 	         PageHelper.startPage(pageNum, pageSize);
                 	    }
                 	        
                 	    qualityCheckList = storageQualitycheckService.queryByQualitycheck(qualityCheck);
                 	    if(qualityCheckList!=null && qualityCheckList.size()>0){
               	          qualityCheckListNew.add(qualityCheckList.get(0));
           	            }
         		}
         }
        }
        PageInfo<StorageQualitycheck> pageInfo = new PageInfo<StorageQualitycheck>(qualityCheckListNew);
        if(pageInfo.getTotal()>0){
        	pageInfo.setStartRow(pageInfo.getStartRow()+1);
        	pageInfo.setEndRow(pageInfo.getEndRow()+1);
        }
        return pageInfo;
    }

    /**
     * 封仓后修改地址
     * @param location
     * @return
     */
    @RequestMapping(value="/updateOrigin", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="封仓后修改地址", notes = "根据库里现场情况，需加功能封仓后需要修改一次地址")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "检验表id", paramType = "query"),
            @ApiImplicitParam(name = "foodbasicinfoId", value = "封仓表id", paramType = "query"),
            @ApiImplicitParam(name = "location", value = "地址信息", paramType = "form")
    })
    public Map<String, Object> updateOrigin(Integer id,Integer foodbasicinfoId,Integer location) {
        StorageQualitycheck storageQualitycheck = new StorageQualitycheck();
        StorageFoodbasicinfo storageFoodbasicinfo = new StorageFoodbasicinfo();
        Map<String, Object> modelMap = new HashMap<String, Object>();
        try {
            storageQualitycheck.setId(id);
            storageQualitycheck.setLocation(location);
            storageQualitycheckService.setQualitycheckType(storageQualitycheck);


            storageFoodbasicinfo.setId(foodbasicinfoId);
            storageFoodbasicinfo.setValidHouseCapacity("0000");
            foodbasicInfoService.updateByPrimaryKey(storageFoodbasicinfo);
            modelMap.put("status", "success");
        } catch (Exception e) {
            modelMap.put("status", "error");
            e.printStackTrace();
        }
        return modelMap;
    }
    
    
    //质检信息主表同步
    @RequestMapping("/qualityMainSynchronization")
    public void qualityMainSynchronization() {
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss.SSSZ");
        List list = DataSynchronization.queryQualityMain();
        Map<String, Object> paramMap = new HashMap<String, Object>();
        List<Map<String,Object>> qualitycheckList = storageQualitycheckService.getAllQualityMain(paramMap);
        for(Map qualitycheckMap:qualitycheckList) {
            int num = 0;
            for(int i=0;i<list.size();i++) {
                Map<String,Object> map = (Map<String,Object>)list.get(i);
                String zjid = ObjectUtils.toString(map.get("zjid"),"");//库点编码
                String refreshTime = ObjectUtils.toString(map.get("refreshTime"),"");
                if(zjid.equals(ObjectUtils.toString(qualitycheckMap.get("zjid"),""))) {
                    if(!refreshTime.equals(format.format(qualitycheckMap.get("updatetime")))) {
                        DataSynchronization.updateQualityMain(map, qualitycheckMap);
                    }
                    break;
                }else if(num == (list.size()-1)){
                    DataSynchronization.insertQualityMain(qualitycheckMap);
                }else {
                    num = num+1;
                }
            }
        }
    }

    //质检信息明细同步
    @RequestMapping("/qualityInfoSynchronization")
    public void qualityInfoSynchronization() {
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss.SSSZ");
        List list = DataSynchronization.queryQualityMain();
        Map<String, Object> paramMap = new HashMap<String, Object>();
        List<Map<String,Object>> qualitycheckList = storageQualitycheckService.getAllQualityInfo(paramMap);
        for(Map qualitycheckMap:qualitycheckList) {
            int num = 0;
            for(int i=0;i<list.size();i++) {
                Map<String,Object> map = (Map<String,Object>)list.get(i);
                String zjid = ObjectUtils.toString(map.get("zjid"),"");//库点编码
                String refreshTime = ObjectUtils.toString(map.get("refreshTime"),"");
                if(zjid.equals(ObjectUtils.toString(qualitycheckMap.get("zjid"),""))) {
                    if(!refreshTime.equals(format.format(qualitycheckMap.get("updatetime")))) {
                        DataSynchronization.updateQuality(map, qualitycheckMap);
                    }
                    break;
                }else if(num == (list.size()-1)){
                    DataSynchronization.insertQuality(qualitycheckMap);
                }else {
                    num = num+1;
                }
            }
        }
    }

    //粮食库存同步
    @RequestMapping("/foodStocksSynchronization")
    public void foodStocksSynchronization() {
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss.SSSZ");
        List list = DataSynchronization.queryQualityMain();
        Map<String, Object> paramMap = new HashMap<String, Object>();
        List<Map<String,Object>> foodStocksList = storageQualitycheckService.getAllFoodStocks(paramMap);
        for(Map foodStocksMap:foodStocksList) {
            int num = 0;
            for(int i=0;i<list.size();i++) {
                Map<String,Object> map = (Map<String,Object>)list.get(i);
                String fcid = ObjectUtils.toString(map.get("fcid"),"");//库点编码
                String refreshTime = ObjectUtils.toString(map.get("refreshTime"),"");
                if(fcid.equals(ObjectUtils.toString(foodStocksMap.get("fcid"),""))) {
                    if(!refreshTime.equals(format.format(foodStocksMap.get("updatetime")))) {
                        DataSynchronization.updateFoodStocks(map, foodStocksMap);
                    }
                    break;
                }else if(num == (list.size()-1)){
                    DataSynchronization.insertFoodStocks(foodStocksMap);
                }else {
                    num = num+1;
                }
            }
        }
    }

}